@@ -236,14 +236,14 @@ class Acquisition(object, metaclass=NumpyDocstringInheritanceMeta):
         image_process_fn : Callable
             image processing function that will be called on each image that gets acquired.
             Can either take two arguments (image, metadata) where image is a numpy array and metadata is a dict
-            containing the corresponding image metadata. Or a 4 argument version is accepted, which accepts (image,
+            containing the corresponding image metadata. Or a three argument version is accepted, which accepts (image,
             metadata, queue), where queue is a Queue object that holds upcoming acquisition events. The function
             should return either an (image, metadata) tuple or a list of such tuples
         event_generation_hook_fn : Callable
             hook function that will as soon as acquisition events are generated (before hardware sequencing optimization
             in the acquisition engine. This is useful if one wants to modify acquisition events that they didn't generate
             (e.g. those generated by a GUI application). Accepts either one argument (the current acquisition event)
-            or three arguments (current event, event_queue)
+            or two arguments (current event, event_queue)
         pre_hardware_hook_fn : Callable
             hook function that will be run just before the hardware is updated before acquiring
             a new image. In the case of hardware sequencing, it will be run just before a sequence of instructions are
@@ -308,18 +308,22 @@ class Acquisition(object, metaclass=NumpyDocstringInheritanceMeta):
         self._initialize_image_processor(**named_args)
         self._initialize_hooks(**named_args)
 
-        # self._remote_acq.start()
+        self._remote_acq.start()
         self._dataset_disk_location = (
-            self._remote_acq.get_storage().get_disk_location()
-            if self._remote_acq.get_storage() is not None
+            self._remote_acq.get_data_sink().get_storage().get_disk_location()
+            if self._remote_acq.get_data_sink() is not None
             else None
         )
 
         self._start_events()
 
         # Load remote storage
-        self._remote_storage_monitor = self._remote_acq.get_storage_monitor()
-        if self._remote_storage_monitor is not None:
+
+        data_sink = self._remote_acq.get_data_sink()
+        if data_sink is not None:
+            ndtiff_storage = data_sink.get_storage()
+            self._remote_storage_monitor = JavaObject('org.micromanager.remote.RemoteStorageMonitor', args=(ndtiff_storage,))
+            ndtiff_storage.add_image_written_listener(self._remote_storage_monitor)
             self._dataset = Dataset(remote_storage_monitor=self._remote_storage_monitor)
             if image_saved_fn is not None:
                 params = signature(image_saved_fn).parameters
@@ -375,7 +379,8 @@ class Acquisition(object, metaclass=NumpyDocstringInheritanceMeta):
 
     def await_completion(self):
         """Wait for acquisition to finish and resources to be cleaned up"""
-        while not self._remote_acq.is_finished():
+        while not self._remote_acq.are_events_finished() or (
+                self._remote_acq.get_data_sink() is not None and not self._remote_acq.get_data_sink().is_finished()):
             time.sleep(1 if self._debug else 0.05)
             self._check_for_exceptions()
         self._remote_acq = None
@@ -513,7 +518,7 @@ class Acquisition(object, metaclass=NumpyDocstringInheritanceMeta):
     def _create_remote_acquisition(self, **kwargs):
         core = Core(port= self._port, timeout=self._timeout)
         acq_factory = JavaObject("org.micromanager.remote.RemoteAcquisitionFactory",
-            port=self._port, args=[core])
+            port=self._port, args=[core], debug=self._debug)
         show_viewer = kwargs['show_display'] == True and (kwargs['directory'] is not None and kwargs['name'] is not None)
 
         self._remote_acq = acq_factory.create_acquisition(
@@ -735,10 +740,12 @@ class MagellanAcquisition(Acquisition):
 
     def _create_remote_acquisition(self, **kwargs):
         if self.magellan_acq_index is not None:
+            #TODO: magellan acquisitions may miss images written
             magellan_api = Magellan()
-            self._remote_acq = magellan_api.create_acquisition(self.magellan_acq_index)
+            self._remote_acq = magellan_api.create_acquisition(self.magellan_acq_index, False).get_acquisition()
             self._event_queue = None
         elif self.magellan_explore:
             magellan_api = Magellan()
-            self._remote_acq = magellan_api.create_explore_acquisition()
+            self._remote_acq = magellan_api.create_explore_acquisition(False).get_acquisition()
             self._event_queue = None
+
